==> lapisworks-1.5.6.6-sources.jar: com/luxof/lapisworks/BeegInfusions/MakeGenericPartAmel.java <==
package com.luxof.lapisworks.BeegInfusions;

import at.petrak.hexcasting.api.casting.OperatorUtils;
import at.petrak.hexcasting.api.casting.eval.CastingEnvironment.HeldItemInfo;
import at.petrak.hexcasting.api.misc.MediaConstants;
import at.petrak.hexcasting.common.items.ItemStaff;

import com.luxof.lapisworks.MishapThrowerJava;
import com.luxof.lapisworks.VAULT.Flags;
import com.luxof.lapisworks.init.Mutables.BeegInfusion;
import com.luxof.lapisworks.init.Mutables.Mutables;
import com.luxof.lapisworks.interop.hextended.LapixtendedInterface;
import com.luxof.lapisworks.items.shit.PartiallyAmelInterface;
import com.luxof.lapisworks.mishaps.MishapNotEnoughItems;
import com.luxof.lapisworks.mixinsupport.GetStacks;
import com.luxof.lapisworks.recipes.HandsInv;
import com.luxof.lapisworks.recipes.ImbuementRec;
import net.minecraft.class_1268;
import net.minecraft.class_1792;
import net.minecraft.class_1799;

import static com.luxof.lapisworks.LapisworksIDs.AMEL;

public class MakeGenericPartAmel extends BeegInfusion {
    private class_1799 stack = null;
    private class_1792 item = null;
    private class_1268 hand = null;
    private int fullInfusionCost = 0;
    private int infusing = 0;

    @Override
    protected void postSetUp() {
        try {
            fullInfusionCost = item instanceof PartiallyAmelInterface ?
                (int)Math.ceil(
                    stack.method_7919() /
                    (double)((PartiallyAmelInterface)item).getAmelWorthInDurability()
                ) : Mutables.getBaseCostForInfusionOf(LapixtendedInterface.getAppropriateFullAmel(item));
        } catch (NullPointerException e) {}
        infusing = Math.min(
            OperatorUtils.getPositiveInt(hexStack, 0, hexStack.size()),
            fullInfusionCost
        );
    }

    @Override
    public boolean test() {
        boolean ret = false;
        for (HeldItemInfo heldInfo : this.heldInfos) {
            ret = true;
            stack = heldInfo.stack();
            item = stack.method_7909();
            hand = heldInfo.hand();
            if (!(item instanceof ItemStaff)) ret = false;
            else if (ctx.getWorld().method_8433().method_8132(
                    ImbuementRec.Type.INSTANCE,
                    new HandsInv(((GetStacks)ctx).getHeldItemStacks()),
                    ctx.getWorld()
                ).isPresent()) ret = false;
        }
        return ret;
    }

    @Override
    public void mishapIfNeeded() {
        int availableAmel = vault.fetch(Mutables::isAmel, Flags.PRESET_Stacks_InvItem_UpToHotbar);
        if (availableAmel < infusing) {
            MishapThrowerJava.throwMishap(new MishapNotEnoughItems(
                AMEL,
                availableAmel,
                infusing
            ));
        }
    }

    @Override
    public Long getCost() { return MediaConstants.SHARD_UNIT * 2 * infusing; }

    @Override
    public void accept() {
        vault.drain(Mutables::isAmel, infusing, Flags.PRESET_Stacks_InvItem_UpToHotbar);

        PartiallyAmelInterface partAmel = LapixtendedInterface.getAppropriatePartAmelGeneric(item);
        class_1792 fullAmel = LapixtendedInterface.getAppropriateFullAmel(item);
        class_1799 newStaff;
        if (infusing == fullInfusionCost) { newStaff = new class_1799(fullAmel); }
        else if (!(item instanceof PartiallyAmelInterface)) {
            newStaff = new class_1799((class_1792)partAmel);
            newStaff.method_7974(
            newStaff.method_7936() - infusing * partAmel.getAmelWorthInDurability()
        );
        } else {
            newStaff = stack.method_7972();
            newStaff.method_7974(
                stack.method_7919() - infusing * partAmel.getAmelWorthInDurability()
            );
        }
        ctx.replaceItem(
            stack -> stack.method_7909() instanceof ItemStaff, 
            newStaff,
            hand
        );
    }
}

==> lapisworks-1.5.6.7-sources.jar: com/luxof/lapisworks/BeegInfusions/MakeGenericPartAmel.java <==
package com.luxof.lapisworks.BeegInfusions;

import at.petrak.hexcasting.api.casting.OperatorUtils;
import at.petrak.hexcasting.api.casting.eval.CastingEnvironment.HeldItemInfo;
import at.petrak.hexcasting.api.misc.MediaConstants;
import at.petrak.hexcasting.common.items.ItemStaff;

import com.luxof.lapisworks.MishapThrowerJava;
import com.luxof.lapisworks.VAULT.Flags;
import com.luxof.lapisworks.init.Mutables.BeegInfusion;
import com.luxof.lapisworks.init.Mutables.Mutables;
import com.luxof.lapisworks.interop.hextended.LapixtendedInterface;
import com.luxof.lapisworks.items.shit.DurabilityPartAmel;
import com.luxof.lapisworks.mishaps.MishapNotEnoughItems;
import com.luxof.lapisworks.mixinsupport.GetStacks;
import com.luxof.lapisworks.recipes.HandsInv;
import com.luxof.lapisworks.recipes.ImbuementRec;
import net.minecraft.class_1268;
import net.minecraft.class_1792;
import net.minecraft.class_1799;

import static com.luxof.lapisworks.LapisworksIDs.AMEL;

public class MakeGenericPartAmel extends BeegInfusion {
    private class_1799 stack = null;
    private class_1792 item = null;
    private class_1268 hand = null;
    private int fullInfusionCost = 0;
    private int infusing = 0;

    @Override
    protected void postSetUp() {
        try {
            fullInfusionCost = item instanceof DurabilityPartAmel ?
                stack.method_7936() * ((DurabilityPartAmel)item).getAmelWorthInDurability()
                : Mutables.getBaseCostForInfusionOf(
                    LapixtendedInterface.getAppropriateFullAmel(item)
                );
        } catch (NullPointerException e) {}
        infusing = Math.min(
            OperatorUtils.getPositiveInt(hexStack, 0, hexStack.size()),
            fullInfusionCost
        );
    }

    @Override
    public boolean test() {
        boolean ret = false;
        for (HeldItemInfo heldInfo : this.heldInfos) {
            ret = true;
            stack = heldInfo.stack();
            item = stack.method_7909();
            hand = heldInfo.hand();
            if (!(item instanceof ItemStaff)) ret = false;
            else if (ctx.getWorld().method_8433().method_8132(
                    ImbuementRec.Type.INSTANCE,
                    new HandsInv(((GetStacks)ctx).getHeldItemStacks()),
                    ctx.getWorld()
                ).isPresent()) ret = false;
            if (ret) break;
        }
        return ret;
    }

    @Override
    public void mishapIfNeeded() {
        int availableAmel = vault.fetch(Mutables::isAmel, Flags.PRESET_Stacks_InvItem_UpToHotbar);
        if (availableAmel < infusing) {
            MishapThrowerJava.throwMishap(new MishapNotEnoughItems(
                AMEL,
                availableAmel,
                infusing
            ));
        }
    }

    @Override
    public Long getCost() { return MediaConstants.SHARD_UNIT * 2 * infusing; }

    @Override
    public void accept() {
        vault.drain(Mutables::isAmel, infusing, Flags.PRESET_Stacks_InvItem_UpToHotbar);

        DurabilityPartAmel partAmel = (DurabilityPartAmel)LapixtendedInterface.getAppropriatePartAmelGeneric(item);
        class_1792 fullAmel = LapixtendedInterface.getAppropriateFullAmel(item);
        class_1799 newStaff;
        if (infusing == fullInfusionCost) { newStaff = new class_1799(fullAmel); }
        else if (!(item instanceof DurabilityPartAmel)) {
            newStaff = new class_1799((class_1792)partAmel);
            newStaff.method_7974(
            newStaff.method_7936() - infusing * partAmel.getAmelWorthInDurability()
        );
        } else {
            newStaff = stack.method_7972();
            newStaff.method_7974(
                stack.method_7919() - infusing * partAmel.getAmelWorthInDurability()
            );
        }
        ctx.replaceItem(
            stack -> stack.method_7909() instanceof ItemStaff, 
            newStaff,
            hand
        );
    }
}
